Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(892)

Unified Diff: third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp

Issue 2370673002: Changed EDisplay to an enum class and renamed its members to be keywords (Closed)
Patch Set: Comment Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp
diff --git a/third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp b/third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp
index d95f1f656d63f77101dd2168c2af526c5b1cb519..b5009c1b789d6e84d85f48e4b8410c160aab5fd3 100644
--- a/third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp
+++ b/third_party/WebKit/Source/core/css/ComputedStyleCSSValueMapping.cpp
@@ -1934,7 +1934,7 @@ const CSSValue* ComputedStyleCSSValueMapping::get(CSSPropertyID propertyID, cons
case CSSPropertyOrder:
return CSSPrimitiveValue::create(style.order(), CSSPrimitiveValue::UnitType::Number);
case CSSPropertyFloat:
- if (style.display() != NONE && style.hasOutOfFlowPosition())
+ if (style.display() != EDisplay::None && style.hasOutOfFlowPosition())
return CSSPrimitiveValue::createIdentifier(CSSValueNone);
return CSSPrimitiveValue::create(style.floating());
case CSSPropertyFont:
@@ -2109,7 +2109,7 @@ const CSSValue* ComputedStyleCSSValueMapping::get(CSSPropertyID propertyID, cons
float value;
if (marginRight.isPercentOrCalc()) {
// LayoutBox gives a marginRight() that is the distance between the right-edge of the child box
// and the right-edge of the containing box, when display == BLOCK. Let's calculate the absolute
// value of the specified margin-right % instead of relying on LayoutBox's marginRight() value.
value = minimumValueForLength(marginRight, toLayoutBox(layoutObject)->containingBlockLogicalWidthForContent()).toFloat();
} else {
@@ -2109,7 +2109,7 @@ const CSSValue* ComputedStyleCSSValueMapping::get(CSSPropertyID propertyID, cons
if (marginRight.isPercentOrCalc()) {
// LayoutBox gives a marginRight() that is the distance between the right-edge of the child box
- // and the right-edge of the containing box, when display == BLOCK. Let's calculate the absolute
+ // and the right-edge of the containing box, when display == EDisplay::Block. Let's calculate the absolute
// value of the specified margin-right % instead of relying on LayoutBox's marginRight() value.
value = minimumValueForLength(marginRight, toLayoutBox(layoutObject)->containingBlockLogicalWidthForContent()).toFloat();

Powered by Google App Engine
This is Rietveld 408576698